@@ -52,7 +52,10 @@ dos_to_posix (std::string file_name)
 
 /** Use slash as directory separator.  On Windows, they can pretty
     much be exchanged.  */
-static std::string
+#if 0
+static /* avoid warning */
+#endif 
+std::string
 slashify (std::string file_name)
 {
   replace_all (file_name, '\\', '/');
@@ -124,9 +127,3 @@ File_name::is_absolute () const
   return (dir_.length () && dir_[0] == DIRSEP) || root_.length ();
 }
 
-#if 0 //STD_STRING
-File_name::File_name (String file_name)
-{
-  *this = File_name (std::string (file_name));
-}
-#endif
