@@ -18,10 +18,10 @@ Interval_t<Real>::infinity ()
 }
 
 template<>
-String
+std::string
 Interval_t<Real>::T_to_string (Real r)
 {
-  return ::to_string (r);
+  return std::to_string (r);
 }
 
 template<>
@@ -32,12 +32,11 @@ Interval_t<int>::infinity ()
 }
 
 template<>
-String
+std::string
 Interval_t<int>::T_to_string (int i)
 {
-  return ::to_string (i);
+  return std::to_string (i);
 }
 
 template INTERVAL__INSTANTIATE (int);
 template INTERVAL__INSTANTIATE (Real);
-
