@@ -47,6 +47,12 @@ namespace std {
     return String_convert::long_string (b);
   }
 
+  std::string
+  to_string (long unsigned b)
+  {
+    return String_convert::unsigned_string (b);
+  }
+
   std::string
   to_string (unsigned u)
   {
