@@ -124,7 +124,7 @@ Context::create_unique_context (SCM n, SCM operations)
   /*
     TODO: use accepts_list_.
   */
-  Link_array<Context_def> path
+  Link_array__Context_def_ path
     = unsmob_context_def (definition_)->path_to_acceptable_context (n, get_output_def ());
 
   if (path.size ())
@@ -132,7 +132,7 @@ Context::create_unique_context (SCM n, SCM operations)
       Context *current = this;
 
       // start at 1.  The first one (index 0) will be us.
-      for (int i = 0; i < path.size (); i++)
+      for (vsize i = 0; i < path.size (); i++)
 	{
 	  SCM ops = (i == path.size () -1) ? operations : SCM_EOL;
 
@@ -182,7 +182,7 @@ Context::find_create_context (SCM n, std::string id, SCM operations)
   /*
     TODO: use accepts_list_.
   */
-  Link_array<Context_def> path
+  Link_array__Context_def_ path
     = unsmob_context_def (definition_)->path_to_acceptable_context (n, get_output_def ());
 
   if (path.size ())
@@ -190,7 +190,7 @@ Context::find_create_context (SCM n, std::string id, SCM operations)
       Context *current = this;
 
       // start at 1.  The first one (index 0) will be us.
-      for (int i = 0; i < path.size (); i++)
+      for (vsize i = 0; i < path.size (); i++)
 	{
 	  SCM ops = (i == path.size () -1) ? operations : SCM_EOL;
 
