@@ -204,7 +204,7 @@ SCM
 Dot_column::calc_positioning_done (SCM smob)
 {
   Grob *me = unsmob_grob (smob);  
-  Link_array<Grob> dots
+  Link_array__Grob_ dots
     = extract_grob_array (me, "dots");
 
   { /*
@@ -212,7 +212,7 @@ Dot_column::calc_positioning_done (SCM smob)
       dots when merging.
     */
     Grob *c = 0;
-    for (int i = dots.size (); i--;)
+    for (vsize i = dots.size (); i--;)
       {
 	Grob *n = dots[i]->get_parent (Y_AXIS);
 	if (c)
@@ -220,20 +220,20 @@ Dot_column::calc_positioning_done (SCM smob)
 	else
 	  c = n;
       }
-    for (int i = dots.size (); i--;)
+    for (vsize i = dots.size (); i--;)
       {
 	Grob *n = dots[i]->get_parent (Y_AXIS);
 	n->relative_coordinate (c, X_AXIS);
       }
   }
 
-  dots.sort (compare_position);
-  for (int i = dots.size (); i--;)
+  vector_sort (dots, &compare_position);
+  for (vsize i = dots.size (); i--;)
     if (!dots[i]->is_live ())
-      dots.del (i);
+      dots.erase (dots.begin () + i);
 
   Dot_configuration cfg;
-  for (int i = 0;i < dots.size (); i++)
+  for (vsize i = 0;i < dots.size (); i++)
     {
       Dot_position dp;
       dp.dot_ = dots[i];
