@@ -179,21 +179,21 @@ is_number_pair (SCM p)
 }
 
 typedef void (*Void_fptr) ();
-Array<Void_fptr> *scm_init_funcs_;
+std::vector<Void_fptr> *scm_init_funcs_;
 
 void add_scm_init_func (void (*f) ())
 {
   if (!scm_init_funcs_)
-    scm_init_funcs_ = new Array<Void_fptr>;
+    scm_init_funcs_ = new std::vector<Void_fptr>;
 
-  scm_init_funcs_->push (f);
+  scm_init_funcs_->push_back (f);
 }
 
 void
 ly_init_ly_module (void *)
 {
-  for (int i = scm_init_funcs_->size (); i--;)
-    (scm_init_funcs_->elem (i)) ();
+  for (vsize i = scm_init_funcs_->size (); i--;)
+    (scm_init_funcs_->at (i)) ();
 
   if (be_verbose_global)
     {
@@ -356,11 +356,11 @@ ly_assoc_cdr (SCM key, SCM alist)
 }
 
 SCM
-ly_string_array_to_scm (Array<std::string> a)
+ly_string_array_to_scm (std::vector<std::string> a)
 {
   SCM s = SCM_EOL;
-  for (int i = a.size () - 1; i >= 0; i--)
-    s = scm_cons (ly_symbol2scm (a[i].c_str ()), s);
+  for (vsize i = a.size (); i ; i--)
+    s = scm_cons (ly_symbol2scm (a[i - 1].c_str ()), s);
   return s;
 }
 
@@ -721,3 +721,22 @@ procedure_arity (SCM proc)
   SCM fixed = scm_car (arity);
   return scm_to_int (fixed);
 }
+
+std::string
+mangle_cxx_identifier (std::string cxx_id)
+{
+  if (cxx_id.substr (0, 3) == "ly_")
+    cxx_id = cxx_id.replace (0, 3, "ly:");
+  else
+    {
+      cxx_id = String_convert::to_lower (cxx_id);
+      cxx_id = "ly:" + cxx_id;
+    }
+  if (cxx_id.substr (cxx_id.length () - 2) == "_p")
+    cxx_id = cxx_id.replace (cxx_id.length () - 2, 1, "?");
+  else if (cxx_id.substr (cxx_id.length () - 2) == "_x")
+    cxx_id = cxx_id.replace (cxx_id.length () - 2, 1, "!");
+
+  cxx_id = replace_all (cxx_id, '_', '-');
+  return cxx_id;
+}
