@@ -21,7 +21,7 @@ protected:
    void process_music ();
 
 private:
-  Link_array<Music> events_;
+  Link_array__Music_ events_;
   Audio_text *audio_;
 };
 
@@ -62,7 +62,7 @@ Lyric_performer::try_music (Music *event)
 {
   if (event->is_mus_type ("lyric-event"))
     {
-      events_.push (event);
+      events_.push_back (event);
       return true;
     }
   return false;
