@@ -51,12 +51,12 @@ LY_DEFINE (ly_otf_font_table_data, "ly:otf-font-table-data", 2, 0, 0,
 
   char ctag [5] = "    ";
 
-  String tag_string = ly_scm2string (tag);
-  strncpy (ctag, tag_string.to_str0 (), tag_string.length ());
+  std::string tag_string = ly_scm2string (tag);
+  strncpy (ctag, tag_string.c_str (), tag_string.length ());
 
-  String tab = otf->get_otf_table (String (ctag));
+  std::string tab = otf->get_otf_table (std::string (ctag));
 
-  return scm_from_locale_stringn ((char const *) tab.to_bytes (), tab.length ());
+  return scm_from_locale_stringn ((char const *) tab.data (), tab.length ());
 }
 
 LY_DEFINE (ly_otf_font_p, "ly:otf-font?", 1, 0, 0,
@@ -71,3 +71,19 @@ LY_DEFINE (ly_otf_font_p, "ly:otf-font?", 1, 0, 0,
 
   return scm_from_bool (otf);
 }
+
+LY_DEFINE (ly_otf_glyph_list, "ly:otf-glyph-list",
+	   1, 0, 0, (SCM font),
+	   "Return a list of glyphnames for @var{font}.")
+{
+  Modified_font_metric *fm
+    = dynamic_cast<Modified_font_metric *> (unsmob_metrics (font));
+
+  Open_type_font *otf = fm ? dynamic_cast<Open_type_font *> (fm->original_font ())
+    : dynamic_cast<Open_type_font *> (unsmob_metrics (font));
+
+
+  SCM_ASSERT_TYPE (otf,font, SCM_ARG1, __FUNCTION__, "OTF font");
+  return otf->glyph_list ();
+
+}
