@@ -79,7 +79,7 @@ private:
     occurs simultaneously then extra space can be added between them.
   */
 
-  Link_array<Spanner> previous_;
+  Link_array__Spanner_ previous_;
   void del_linespanner (Spanner *);
 
   void create_text_grobs (Pedal_info *p, bool);
@@ -264,8 +264,8 @@ Piano_pedal_engraver::create_text_grobs (Pedal_info *p, bool mixed)
 	  if (previous_.size ())
 	    // add extra space below the previous already-occuring pedal
 	    Side_position_interface::add_support (p->line_spanner_,
-						  previous_.top ());
-	  previous_.push (p->line_spanner_);
+						  previous_.back ());
+	  previous_.push_back (p->line_spanner_);
 	}
     }
 
@@ -386,9 +386,9 @@ Piano_pedal_engraver::create_bracket_grobs (Pedal_info *p, bool mixed)
 	    // position new pedal spanner below the current one
 	    */
 	  if (previous_.size ())
-	    Side_position_interface::add_support (p->line_spanner_, previous_.top ());
+	    Side_position_interface::add_support (p->line_spanner_, previous_.back ());
 
-	  previous_.push (p->line_spanner_);
+	  previous_.push_back (p->line_spanner_);
 	}
     }
 
@@ -438,9 +438,9 @@ Piano_pedal_engraver::finalize ()
 void
 Piano_pedal_engraver::del_linespanner (Spanner *g)
 {
-  int idx = previous_.find_index (g);
-  if (idx >= 0)
-    previous_.del (idx);
+  vsize idx = find (previous_, g) - previous_.begin ();
+  if (idx != VPOS && idx < previous_.size ())
+    previous_.erase (previous_.begin () + idx);
 }
 
 void
