@@ -5,8 +5,8 @@
 ;;;; (c) 1998--2006 Han-Wen Nienhuys <hanwen@cs.uu.nl>
 ;;;;                 Jan Nieuwenhuizen <janneke@gnu.org>
 
-;;;; distances are given in linethickness (thicknesses) and
-;;;; staffspace (distances)
+;;;; distances are given in line-thickness (thicknesses) and
+;;;; staff-space (distances)
 
 ;;;; WARNING: the meta field should be the last one.
 ;;;; WARNING: don't use anonymous functions for initialization.
@@ -174,7 +174,7 @@
 	;; Ross. page 151 lists other values, we opt for a leaner look
 	;;
 	;; TODO:
-	;; kern should scale with linethickness too.
+	;; kern should scale with line-thickness too.
 	(kern . 3.0)
 	(thin-kern . 3.0)
 	(hair-thickness . 1.9)
@@ -287,7 +287,7 @@
 
 	;; Whe have some unreferenced problems here.
 	;;
-	;; If we shorten beamed stems less than normal stems (1 staffspace),
+	;; If we shorten beamed stems less than normal stems (1 staff-space),
 	;; or high order less than 8th beams, patterns like
 	;;     c''4 [c''8 c''] c''4 [c''16 c]
 	;; are ugly (different stem lengths).
@@ -316,7 +316,7 @@
 	(positioning-done . ,ly:break-align-interface::calc-positioning-done)
 	(X-extent . ,ly:axis-group-interface::width)
 	(break-align-orders . ;; end of line
-			    #((instrument-name
+			    #((
 			       left-edge
 			       ambitus
 			       breathing-sign
@@ -328,7 +328,7 @@
 			       custos)
 
 			      ;; unbroken
-			      (instrument-name
+			      (
 			       left-edge
 			       ambitus
 			       breathing-sign
@@ -340,7 +340,7 @@
 			       time-signature custos)
 
 			      ;; begin of line
-			      (instrument-name
+			      (
 			       left-edge
 			       ambitus
 			       breathing-sign
@@ -724,31 +724,18 @@
 				spanner-interface))))))
     (InstrumentName
      . (
-	(breakable . #t)
-	(Y-offset . ,(ly:make-simple-closure
-		      `(,+ ,(ly:make-simple-closure
-			     (list ly:self-alignment-interface::y-aligned-on-self))
-			   ,(ly:make-simple-closure
-			     (list ly:side-position-interface::y-aligned-on-support-refpoints)))))
-	
-	;; This direction is for aligned_on_support_refpoints
-	;; (?) --hwn
-	(direction . ,CENTER)
-	(space-alist . (
-			(left-edge . (extra-space . 1.0))))
-
-	(self-alignment-Y . 0)
-	(stencil . ,ly:text-interface::print)
-	(break-align-symbol . instrument-name)
-	(break-visibility . ,begin-of-line-visible)
-	(baseline-skip . 2)
-	(side-axis . ,X)
-	(meta . ((class . Item)
-		 (interfaces . (font-interface
-				self-alignment-interface
+	(style . text)
+	(padding . 0.3)
+	(stencil . ,ly:system-start-delimiter::print)
+	(collapse-height . 5.0)
+	(X-offset . ,ly:side-position-interface::x-aligned-side)
+	(direction . ,LEFT)
+	(Y-offset . -0.75)
+	(Y-extent . #f)
+	(meta . ((class . Spanner)
+		 (interfaces . (system-start-text-interface
 				side-position-interface
-				text-interface
-				break-aligned-interface))))))
+				font-interface))))))
 
     (KeyCancellation
      . (
@@ -892,7 +879,7 @@
 
 	(stencil . ,ly:lyric-extender::print)
 
-	(thickness . 0.8) ; linethickness
+	(thickness . 0.8) ; line-thickness
 	(minimum-length . 1.5)
 	(Y-extent . (0 . 0))
 	(meta . ((class . Spanner)
@@ -1606,6 +1593,7 @@
 				side-position-interface
 				font-interface))))))
 
+
     (SystemStartSquare
      . (
 	(Y-extent . #f)
@@ -1901,24 +1889,6 @@
 				hara-kiri-group-interface
 				vertically-spaceable-interface))))))
 
-    (VocalName
-     . (
-	(breakable . #t)
-	(Y-offset . ,ly:side-position-interface::y-aligned-on-support-refpoints)
-	(direction . ,CENTER)
-	(space-alist . ((left-edge . (extra-space . 1.0))))
-	(break-align-symbol . instrument-name)
-	(stencil . ,ly:text-interface::print)
-	(break-align-symbol . clef)
-	(break-visibility . ,begin-of-line-visible)
-	(baseline-skip . 2)
-	(side-axis . ,Y)
-	(meta . ((class . Item)
-		 (interfaces . (font-interface
-				self-alignment-interface
-				side-position-interface
-				text-interface
-				break-aligned-interface))))))
 
     (VoltaBracket
      . (
@@ -1929,8 +1899,8 @@
 	(font-encoding . fetaNumber)
 	(Y-offset . ,ly:side-position-interface::y-aligned-side)
 	(side-axis . ,Y)
-	(thickness . 1.6)  ;;  linethickness
-	(edge-height . (2.0 . 2.0)) ;; staffspace;
+	(thickness . 1.6)  ;;  line-thickness
+	(edge-height . (2.0 . 2.0)) ;; staff-space;
 	(minimum-space . 5)
 	(font-size . -4)
 	(meta . ((class . Spanner)
